DownloadApiRequest<T> class abstract

Download request

Inheritance

Constructors

DownloadApiRequest({required String baseUrl, required String endpoint, required HttpMethod method, ProgressCallback? onProgress})

Properties

baseUrl String
finalinherited
body Object?
no setterinherited
cancelToken → CancelToken?
no setterinherited
completeURL String
no setterinherited
contentLengthHeaderKey String
no setter
contentTypeHeader String?
no setterinherited
decoder ResponseDecoder<T>
finalinherited
deleteFileOnFailure bool
no setter
endpoint String
finalinherited
extra Map<String, dynamic>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setterinherited
isMocked bool
Mocking helpers
no setterinherited
method HttpMethod
finalinherited
mockAssetPath String?
no setterinherited
onProgress → ProgressCallback?
final
queryParameters Map<String, dynamic>?
no setterinherited
responseType → ResponseType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useIsolateDecode bool
If decoder is heavy, set to true and provide a top-level decoder function.
no setterinherited

Methods

generateFilePath(Headers headers) FutureOr<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited