MultipartApiRequest<T> class abstract

Multipart request

Inheritance

Constructors

MultipartApiRequest({required String baseUrl, required String endpoint, required HttpMethod method, required ResponseDecoder<T> decoder})

Properties

baseUrl String
finalinherited
body Object?
no setterinherited
cancelToken → CancelToken?
no setterinherited
completeURL String
no setterinherited
contentTypeHeader String?
no setterinherited
decoder ResponseDecoder<T>
finalinherited
endpoint String
finalinherited
extra Map<String, dynamic>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setteroverride
isMocked bool
Mocking helpers
no setterinherited
method HttpMethod
finalinherited
mockAssetPath String?
no setterinherited
queryParameters Map<String, dynamic>?
no setterinherited
responseType → ResponseType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useIsolateDecode bool
If decoder is heavy, set to true and provide a top-level decoder function.
no setterinherited

Methods

generateFormData() Future<FormData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited