StatefulColor class

Constructors

StatefulColor(Color base, [Color? hover, Color? active, Color? disabled])
const

Properties

active Color?
final
base Color
final
disabled Color?
final
hashCode int
The hash code for this object.
no setterinherited
hover Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(StatefulColor other, double t) StatefulColor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited